//   Copyright 2013 Christian Gjerde Jensen

//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at

//       http://www.apache.org/licenses/LICENSE-2.0

//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

///////////////////////
// CONTEXT AWARENESS //
///////////////////////

var context = function() {
  var currentLocation;
  var supportsGeolocation = true;

  //Load location from HTML5 Web Storage if it was already determined this session
  if (sessionStorage.getItem("currentLocation") !== null) {
    currentLocation = sessionStorage.getItem("currentLocation");
  } else {
    fetchLocation();
  }

  function fetchLocation() {
    if (navigator.geolocation) {
      navigator.geolocation.getCurrentPosition(function(position) {
        $.ajax({
          'url': 'http://api.geonames.org/findNearbyPlaceNameJSON',
          'data': {'username' : 'YOUR_GEONAMES_USERNAME', 'lat' : position.coords.latitude, 'lng' : position.coords.longitude},
          'success': function(data) { currentLocation = data.geonames[0].name; sessionStorage.setItem("currentLocation", data.geonames[0].name); },
          'dataType': 'json',
          'jsonp': 'json.wrf'
        });
      });
    }
    else {
      supportsGeolocation = false;
    }
  }

  function getLocation() {
    if (currentLocation) {
      return currentLocation;
    } else {
      return false;
    }
  }

  function getTime() {
    var date = new Date();
    var hours = date.getHours();

    if (hours <= 11) {
      return "Morgen";
    } else if (hours <= 17) {
      return "Ettermiddag";
    } else {
      return "Kveld";
    }
  }

  return {
    getLocation: getLocation,
    getTime: getTime
  };
}();